@@ -24,7 +24,8 @@ class WTSpawnController():
                      "sleep-increment": .125,  # Incremental sleep value
                      "expire": -1,  # Default: no expiration
                      "error": self.default_error,  # Default error callback,
-                     "hosts": ["localhost"]  # Where to run the command. Default locally
+                     "hosts": ["localhost"],  # Where to run the command. Default locally
+                     "hooks": {}  # hooks and their parms.  Example: hooks: {hook_function: {parmA: "blah", parmB: "bleck"}}
                      }
 
     # clean out any promises that have resolved
@@ -74,6 +75,7 @@ class WTSpawnController():
 
             loop_counter += 1
             self.promises_gc()
+        
 
         '''
         The "kill switch" is there in case the user's app wants to pre-emptively stop this command from running.
@@ -95,3 +97,25 @@ class WTSpawnController():
     def set_parms(self, parms):
         for k, v in parms.items():
             self.args[k] = v
+
+
+    # Add a new hook.  If command patter already exists, add the functions to it otherwise create it.
+    def add_hook(self, pattern, function, parms):
+        if pattern in self.args['hooks']:
+            if function in ["hooks"][pattern]:
+                self.args["hooks"][pattern][function] = {parms}
+            else:
+                self.args["hooks"][pattern] = {function: {parms}}
+        else:
+            self.args["hooks"] = {pattern : {function: parms}}
+
+    
+    # Remove all hooks
+    def remove_hooks(self, pattern = None):
+        if not pattern:
+            self.args["hooks"] = {}
+        else:
+            if pattern in self.args["hooks"]:
+                del self.args["hooks"][pattern]
+        
+        
\ No newline at end of file
